@@ -10,6 +10,7 @@
 #
 # Caveats:
 #
+require 'facter/util/posix'
 
 Facter.add(:kernelrelease) do
   setcode 'uname -r'
@@ -20,6 +21,13 @@ Facter.add(:kernelrelease) do
   setcode 'oslevel -s'
 end
 
+Facter.add("kernelrelease") do
+  confine :kernel => :openbsd
+  setcode do
+    Facter::Util::POSIX.sysctl("kern.version").split(' ')[1]
+  end
+end
+
 Facter.add(:kernelrelease) do
   confine :kernel => "hp-ux"
   setcode do
