@@ -12,7 +12,5 @@
 
 Facter.add(:lsbdistrelease) do
   confine :kernel => [ :linux, :"gnu/kfreebsd" ]
-  setcode do
-    Facter::Core::Execution.exec('lsb_release -r -s 2>/dev/null')
-  end
+  setcode 'lsb_release -r -s 2>/dev/null'
 end
