@@ -47,10 +47,16 @@ else
       { 'Product(?: Name)?:' => 'boardproductname' },
       { 'Serial Number:'   => 'boardserialnumber' }
     ],
+    '[Bb][Ii][Oo][Ss] [Ii]nformation' => [
+      { '[Vv]endor:' => 'bios_vendor' },
+      { '[Vv]ersion:' => 'bios_version' },
+      { '[Rr]elease [Dd]ate:' => 'bios_release_date' }
+    ],
     '[Ss]ystem [Ii]nformation' => [
       { 'Manufacturer:'    => 'manufacturer' },
       { 'Product(?: Name)?:' => 'productname' },
-      { 'Serial Number:'   => 'serialnumber' }
+      { 'Serial Number:'   => 'serialnumber' },
+      { 'UUID:'   => 'uuid' }
     ],
     '(Chassis Information|system enclosure or chassis)' => [
       { '(?:Chassis )?Type:' => 'type' }
