@@ -17,6 +17,7 @@
 # Caveats:
 #
 
+require 'facter/util/operatingsystem'
 require 'facter/util/file_read'
 
 Facter.add(:operatingsystemrelease) do
@@ -71,6 +72,24 @@ Facter.add(:operatingsystemrelease) do
   end
 end
 
+Facter.add(:operatingsystemrelease) do
+  confine :operatingsystem => 'LinuxMint'
+  setcode do
+    if release = Facter::Util::FileRead.read('/etc/linuxmint/info')
+      if match = release.match(/RELEASE\=(\d+)/)
+        match[1]
+      end
+    end
+  end
+end
+
+Facter.add(:operatingsystemrelease) do
+confine :operatingsystem => 'CumulusLinux'
+  setcode do
+    Facter::Util::Operatingsystem.os_release['VERSION_ID']
+  end
+end
+
 Facter.add(:operatingsystemrelease) do
   confine :operatingsystem => %w{SLES SLED OpenSuSE}
   setcode do
