@@ -1,30 +1,29 @@
 # mamufacturer.rb
 # Support methods for manufacturer specific facts
 
-module Facter::Manufacturer
+require 'facter/util/posix'
 
+module Facter::Manufacturer
   def self.get_dmi_table()
     case Facter.value(:kernel)
     when 'Linux', 'GNU/kFreeBSD'
-      return nil unless FileTest.exists?("/usr/sbin/dmidecode")
-
-      output=%x{/usr/sbin/dmidecode 2>/dev/null}
+      cmd = '/usr/sbin/dmidecode'
     when 'FreeBSD'
-      return nil unless FileTest.exists?("/usr/local/sbin/dmidecode")
-
-      output=%x{/usr/local/sbin/dmidecode 2>/dev/null}
+      cmd = '/usr/local/sbin/dmidecode'
     when 'NetBSD', 'DragonFly'
-      return nil unless FileTest.exists?("/usr/pkg/sbin/dmidecode")
-
-      output=%x{/usr/pkg/sbin/dmidecode 2>/dev/null}
+      cmd = '/usr/pkg/sbin/dmidecode'
     when 'SunOS'
-      return nil unless FileTest.exists?("/usr/sbin/smbios")
+      cmd = '/usr/sbin/smbios'
+    end
 
-      output=%x{/usr/sbin/smbios 2>/dev/null}
-    else
-      output=nil
+    if cmd and (output = Facter::Core::Execution.exec("#{cmd} 2>/dev/null"))
+
+      if output.respond_to?(:force_encoding)
+        output.force_encoding(Encoding::ASCII_8BIT)
+      end
+
+      return output
     end
-    return output
   end
 
   def self.dmi_find_system_info(name)
@@ -54,7 +53,7 @@ module Facter::Manufacturer
     name.each do |sysctlkey,facterkey|
       Facter.add(facterkey) do
         confine :kernel => [:openbsd, :darwin]
-        setcode "sysctl -n #{sysctlkey} 2>/dev/null"
+        setcode { Facter::Util::POSIX.sysctl(sysctlkey) }
       end
     end
   end
